@@ -10,7 +10,7 @@ in Python with many simple yet powerful features.
 
 from .client import Client
 from .errors import HTTPException, BadRequest, Unauthorized, Forbidden, RateLimited, ClientNotReady
-from .webhook import TopGGVotePayload, DiscordBotListPayload
+from .webhook import TopGGVotePayload, DiscordBotListVotePayload
 from .cog import NoTokenSet
 from .webhook import create_webhook_server, run_webhook_server
 
@@ -29,7 +29,7 @@ __all__ = (
     'DBLClient',
     'TopGGClient',
     'TopGGVotePayload',
-    'DiscordBotListPayload',
+    'DiscordBotListVotePayload',
     'NoTokenSet',
     'create_webhook_server',
     'run_webhook_server'
@@ -40,4 +40,4 @@ __title__ = 'toppy'
 __authors__ = ('The Master', 'chawkk6404')
 __license__ = 'MIT'
 __copyright__ = '2022-present The Master and chawkk6404'
-__version__ = '1.3.7'
+__version__ = '1.4.0'
